/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;


import java.awt.Canvas;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.Point2D;
import java.awt.geom.NoninvertibleTransformException;
import java.awt.RenderingHints;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionAdapter;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;


@SuppressWarnings("serial")
class MotorCanvas extends Canvas {
	protected static double sRef = .6;
	
	protected SPObject content;

	protected ScaleCanvas  scaleCanvas;
	protected VisualCanvas visualCanvas;
	protected InfoCanvas   infoCanvas;
	
	protected AffineTransform t;
	protected AffineTransform t0;
	protected BufferedImage   bi;
	protected Graphics2D      gBi;
	
	protected double scale;
	protected double oldScale;
	protected volatile Point2D.Double cursorLocation;
	protected volatile Point2D.Double dCursorLocation;
	
	protected boolean button;
	protected boolean scaling;

	
	public MotorCanvas(SPObject c, ScaleCanvas s, VisualCanvas v, InfoCanvas i) {
		content = c;
		scaleCanvas = s;
		visualCanvas = v;
		infoCanvas = i;
		oldScale = scale = 1;
		cursorLocation = new Point2D.Double();
		dCursorLocation = new Point2D.Double();
		scaling = false;
		
		addMouseMotionListener(new MouseMotionAdapter() {
			protected Point2D.Double p = new Point2D.Double();
			public void mouseHandle(MouseEvent e) {
				try {
					t.inverseTransform(e.getPoint(), p);
				}
				catch(NoninvertibleTransformException e1) { e1.printStackTrace(); }
				
				dCursorLocation.setLocation(p.x - cursorLocation.x, p.y - cursorLocation.y);
				if(visualCanvas.contains((int)p.x, (int)p.y)) {
					cursorLocation.setLocation(p);
				}
				scaleCanvas.repaint();
				visualCanvas.repaint();
			}
			public void mouseMoved(MouseEvent e)   { mouseHandle(e); }
			public void mouseDragged(MouseEvent e) {
				mouseHandle(e);
				SPObject current = SPObject.current;
				if((current != null) & visualCanvas.contains((int)p.x, (int)p.y)) {
					current.handleDrag(dCursorLocation);
				}
			}
		});
		
		addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				button = true;
				visualCanvas.pick();
				SPObject current = SPObject.current;
				if(current != null) {
					current.handlePress(e);
					scaleCanvas.repaint();
					visualCanvas.repaint();
				}
			}
			
			public void mouseReleased(MouseEvent e) {
				button = false;
				scaleCanvas.repaint();
			}
		});
		
		addKeyListener(new KeyAdapter() {
			public void keyPressed(KeyEvent e) {
				switch(e.getKeyCode()) {
				case KeyEvent.VK_S :
					scaling = !scaling;
				case KeyEvent.VK_R :
					resetTransform();
					repaint();
					break;
				default :
					break;
				}
			}
		});
	}
	
	public void update(Graphics g) {
		paint(g);
	}
	
	public void paint(Graphics g) {
		if(t == null) {
			resetTransform();
			t0 = new AffineTransform();
			bi = (BufferedImage)createImage(getWidth(), getHeight());
			gBi = bi.createGraphics();
			gBi.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
			gBi.setBackground(Color.lightGray);
			requestFocusInWindow();
		}
		gBi.setTransform(t0);
		gBi.clearRect(0, 0, getWidth(), getHeight());
		
		t.translate(cursorLocation.x, cursorLocation.y);
		t.scale(scale / oldScale, scale / oldScale);
		t.translate(-cursorLocation.x, -cursorLocation.y);
		gBi.setTransform(t);
		
		content.draw(gBi, SPObject.Style.MOTOR);
		g.drawImage(bi, 0, 0, null);
	}

	public void resetTransform() {
		t = new AffineTransform();
		t.translate(getWidth() * (1. - sRef) / 2, getHeight() * (1. - sRef) / 2);
		t.scale(sRef, sRef);
		oldScale = scale = 1;
	}
	
	public void setScale(double s) {
		if(scaling) {
			oldScale = scale;
			scale = s;
			infoCanvas.setScale(s);
		}
		repaint();
	}
}
