/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;


import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.event.MouseEvent;
import java.awt.geom.Point2D;


public abstract class SPObject {
	public enum Style {
		VISUAL,
		SCALE,
		MOTOR,
		ID
	}
	
	protected static int nextId = 0;
	protected static int maxId = 255;
	protected static SPObject[] objectsArray = new SPObject[maxId];
	protected static volatile SPObject current;
	
	protected SPComposite parent;
	protected Color id;
	protected Point2D.Double location;
	
	public SPObject(Point2D.Double l) {
		int idTmp = nextId++;
		try {
			objectsArray[idTmp] = this;			
		} catch (IndexOutOfBoundsException e) {
			throw new RuntimeException("Maximum SPObject creation reached");
		}
		id = new Color(idTmp, idTmp, idTmp);
		location = l;
	}
	
	public void draw(Graphics2D g, Style style) {
		g.translate(location.x, location.y);
		render(g, style);
		g.translate(-location.x, -location.y);
	}

	public abstract void render(Graphics2D g, Style style);


	public void handleDrag(Point2D.Double d) {};
	public void handlePress(MouseEvent e) {
		if(parent != null) {
			parent.handlePress(e);
		}
	};
}
