/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;


import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.Point2D;


public class SPRectangle extends SPObject {
	protected Point2D.Double size;
	protected Color scale;
	
	protected Color bg;
	protected Color fg;
	
	protected String text;
	
	public SPRectangle(Point2D.Double l, Point2D.Double s, float sc, Color b, Color f, String t) {
		super(l);
		size = s;
		
		int sci = (int)(sc * ScaleCanvas.s0);
		if(sci < 0) {
			sci = 0;
		} else if(sci > 255) {
			sci = 255;
		}
		scale = new Color(sci, sci, sci);
		
		bg = b;
		fg = f;
		
		text = t;
	}

	public SPRectangle(Point2D.Double s, float sc, Color b, Color f, String t) {
		this(new Point2D.Double(), s, sc, b, f, t);
	}
	
	public SPRectangle(double x, double y, double width, double height, float sc, Color b, Color f, String t) {
		this(new Point2D.Double(x, y), new Point2D.Double(width, height), sc, b, f, t);
	}
	
	public SPRectangle(double width, double height, float sc, Color b, Color f, String t) {
		this(new Point2D.Double(), new Point2D.Double(width, height), sc, b, f, t);
	}
	
	public void render(Graphics2D g, Style style) {
		int x = (int)size.x;
		int y = (int)size.y;
		
		switch(style) {
		case VISUAL :
			if(bg != null) {
				g.setColor(bg);
				g.fillRect(0, 0, x, y);
			}
			if(fg != null) {
				g.setColor(fg);
				g.drawRect(0, 0, x - 1, y - 1);
			}
			if(text != null) {
				g.setClip(3, 2, x-6, y-4);
				g.drawString(text, 4f, 9f);
				g.setClip(null);
			}
			break;
			
		case SCALE :
			g.setColor(scale);
			g.fillRect(0, 0, x, y);
			break;
			
		case MOTOR :
			g.setColor(Color.lightGray);
			g.fillRect(0, 0, x, y);
			g.setColor(Color.black);
			g.drawRect(0, 0, x - 1, y - 1);
			break;
			
		case ID :
			g.setColor(id);
			g.fillRect(0, 0, x, y);
			break;
		}
	}
	
	

}
