/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.event.MouseEvent;
import java.awt.geom.Point2D;

public class SPWindow extends SPComposite {
	protected static int titleHeight = 12; // 10
	protected static int boxSize     =  8; // 6
	
	
	protected Point2D.Double size;
	protected SPRectangle titleBar;
	protected SPRectangle resize;
	
	public SPWindow(int x, int y, int width, int height, String title) {
		this(new Point2D.Double(x, y), new Point2D.Double(width, height), title);
	}
	
	public SPWindow(Point2D.Double l, Point2D.Double s, String title) {
		super(l);
		size = s;
		
		if(size.y < titleHeight + 2 * boxSize) { size.y = titleHeight + 2 *boxSize; }
		
		// background
		addObject(new SPRectangle(size, 1, Color.white, Color.black, null));
		
		// title bar
		addObject(titleBar = new SPRectangle(size.x, titleHeight, 2, Color.lightGray, Color.black, "    " + title) {
			protected SPWindow window = SPWindow.this;
			public void handleDrag(Point2D.Double d) {
				window.location.x += d.x;
				window.location.y += d.y;
			}
		});
		
		// close box
		addObject(new SPRectangle(2, 2, boxSize, boxSize, 5, Color.red.brighter(), Color.black, null) {
			protected SPWindow window = SPWindow.this;
			public void handlePress(MouseEvent e) {
				window.parent.removeObject(window);
			}
			public void render(Graphics2D g, Style style) {
				super.render(g, style);
				switch(style) {
				case VISUAL:
					g.setColor(Color.black);
					g.drawLine(2, 2, boxSize - 3, boxSize - 3);
					g.drawLine(2, boxSize - 3, boxSize - 3, 2);
					break;
					
				default:
					break;
				}
			}
		});
		
	}
		
	public void handlePress(MouseEvent e) {
		parent.moveToFront(this);
	}
}
