/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
//import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;
import java.awt.image.BufferedImage;

//import java.awt.image.renderable.ParameterBlock;
//import javax.media.jai.*;

@SuppressWarnings("serial")
class ScaleCanvas extends Canvas {
	// reference scale
	protected static int s0 = 30;
	// half size of the box where the max scale is computed
	protected static int ws = 2;
	protected static int ws2 = (2*2 + 1)*(2*2 + 1);
	

	protected SPObject content;
	
	protected MotorCanvas motorCanvas;
	
	protected Point2D.Double cursorLocation;
	protected Color  cursorColor;
	
	protected BufferedImage   bi;
	protected Graphics2D      gbi;
	protected AffineTransform t;
	protected AffineTransform ti;
	
//	protected KernelJAI kernel;
//	protected ParameterBlock pb;
//	protected PlanarImage target;
	protected int[] pb;
	
	
	public ScaleCanvas(SPObject c) {
		content = c;
		cursorLocation = new Point2D.Double();
		cursorColor = Color.white;
		pb = new int[(2*ws + 1)*(2*ws + 1)];
	}
	
	public void setMotorCanvas(MotorCanvas mc) {
		motorCanvas = mc;
		cursorLocation = motorCanvas.cursorLocation;
	}
	
	public void update(Graphics g) {
		paint(g);
	}
	
	public void paint(Graphics g) {
		Graphics2D graphics2D = (Graphics2D)g;

		if(bi == null) {
			bi = (BufferedImage)createImage(getWidth() + 2*ws, getHeight() + 2*ws);	
			gbi = bi.createGraphics();
//			gbi.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
			gbi.setBackground(new Color(s0, s0, s0));
			ti = new AffineTransform();
			t = new AffineTransform();
			t.translate(ws, ws);
			t.scale(.5, .5);
		}
		
		gbi.setTransform(ti);
		gbi.clearRect(0, 0, getWidth() + 2*ws, getHeight() + 2*ws);
		gbi.setTransform(t);
		
		content.draw(gbi, SPObject.Style.SCALE);
		
		int x = (int)cursorLocation.x >> 1;
		int y = (int)cursorLocation.y >> 1;
		
//		int s = 0;
//		int smax = s0;
		float smean = 0;
//		if(!motorCanvas.button){
			bi.getRGB(x, y, 2*ws + 1, 2*ws + 1, pb, 0, 2*ws + 1);
			for(int i = 0; i < ws2; ++i){
//				s = pb[i] & 0xff;
//				if(s > smax){ smax = s; }
				smean += pb[i] & 0xff;
			}
			smean /= ws2;
//		}
//		motorCanvas.setScale((float)(smax) / s0);
		motorCanvas.setScale(smean / s0);
		
		
		graphics2D.drawImage(bi, -ws, -ws, null);
		
		graphics2D.setColor(cursorColor);
		graphics2D.drawLine(x - 4, y, x - 2, y);
		graphics2D.drawLine(x, y - 4, x, y - 2);
		graphics2D.drawLine(x + 4, y, x + 2, y);
		graphics2D.drawLine(x, y + 4, x, y + 2);

		
//		float[] data = new float[3];
//		for(int i = 0; i < 3; ++i) {
//			data[i] = 1F / 3;
//		}
//		kernel = new KernelJAI(3,3, 1, 1, data, data);
//		pb = new ParameterBlock();
//		pb.addSource(bi);
//		pb.add(kernel);
		
//		target = JAI.create("convolve", pb, null);
		
//		graphics2D.drawImage(target.getAsBufferedImage(), 0, 0, null);		
	}

}
