/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Container;
import java.awt.Graphics;


@SuppressWarnings("serial")
public class SemanticPointing extends Container {
	protected static SemanticPointing instance;
		
	protected SPComposite content;
	protected SPComposite desktop;
	
	protected VisualCanvas visualCanvas;
	protected ScaleCanvas scaleCanvas;
	protected MotorCanvas motorCanvas;
	protected InfoCanvas infoCanvas;  

	private boolean laidOut = false;

	protected SemanticPointing(int width, int height) {
		instance = this;
			
		// objects to display
		content = new SPComposite();
		desktop = new SPComposite();
		
		// 3 canvas : visual space, scale map & motor space
		infoCanvas = new InfoCanvas();
		
		visualCanvas = new VisualCanvas(content);
		scaleCanvas = new ScaleCanvas(content);
		motorCanvas = new MotorCanvas(content, scaleCanvas, visualCanvas, infoCanvas);
		scaleCanvas.setMotorCanvas(motorCanvas);
		visualCanvas.setMotorCanvas(motorCanvas);
			
		// setting up the layout of the window
		setLayout(null);

		add(infoCanvas);
		add(visualCanvas);
		add(scaleCanvas);
		add(motorCanvas);
		
		setBackground(Color.white);
		setCursor(new Cursor(Cursor.CROSSHAIR_CURSOR));
		
		// adding desktop background & desktop content
		content.addObject(new SPRectangle(0, 0, width >> 1, width * 3 >> 3, 1, new Color(200, 200, 255), null, null));
		content.addObject(desktop);
		
		// testing
//		content.addObject(new SPWindow(10, 10, 100, 75, "note"));
		content.addObject(new SPResizableWindow(126, 10, 100, 75, "resizable"));
		content.addObject(new SPImageWindow(10, 10, 106, 278, "CHI 2004", "chi2004"));
//		content.addObject(new SPImageWindow(70, 130, 280, 80, "Semantic Pointing", "semanticPointing"));
		desktop.addObject(new SPIcon(360, 20, "chi2004"));
		desktop.addObject(new SPIcon(360, 50, null));
	}
	
	public void paint(Graphics g) {
		if(!laidOut) {
			int w11 = getWidth();
			int w12 = w11 >> 1;
			int w14 = w12 >> 1;
			int w18 = w14 >> 1;
			int h12 = w12 * 3 >> 2;
			int h14 = h12 >> 1;
			
			
			visualCanvas.setLocation(0, 0);
			visualCanvas.setSize(w12, h12);
			motorCanvas.setLocation(w12, 0);
			motorCanvas.setSize(w12, h12);
			scaleCanvas.setLocation(w12 - w18, h12);
			scaleCanvas.setSize(w14, h14);
			infoCanvas.setLocation(w12 + w18, h12);
			infoCanvas.setSize(w14 + w18, h14);
			infoCanvas.setScale(1.);
			laidOut = true;
		}
	}
}
