/*
    Copyright (C) 2004-2006  Renaud Blanch

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package semanticPointing;


import java.awt.BasicStroke;
import java.awt.Canvas;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;
import java.awt.RenderingHints;
import java.awt.Stroke;
import java.awt.image.BufferedImage;


@SuppressWarnings("serial")
class VisualCanvas extends Canvas {
	protected SPObject content;
	
	protected BufferedImage pickingMap;
	protected Graphics2D    gPickingMap;
	
	protected BufferedImage bi;
	protected Graphics2D    gBi;
	
	protected MotorCanvas motorCanvas;
	
	// cursor stuff
	protected Point2D.Double cursorLocation;
	protected static int[] x = {0,  0,  3,  6,  9,  6, 10};
	protected static int[] y = {0, 14, 11, 17, 16, 10, 10};
	protected Stroke shadowStroke;
	protected Stroke cursorStroke;
	protected Color shadowColor;

	
	public VisualCanvas(SPObject c) {
		content = c;
		shadowStroke = new BasicStroke(2, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND);
		cursorStroke = new BasicStroke(1, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL);
		shadowColor = new Color(0, 0, 0, 60);
	}
	
	public void setMotorCanvas(MotorCanvas mc) {
		motorCanvas = mc;
		cursorLocation = motorCanvas.cursorLocation;
	}
	
	public void pick() {
		try {
			int objectId = pickingMap.getRGB((int)cursorLocation.x, (int)cursorLocation.y) & 0xff;
			SPObject.current = SPObject.objectsArray[objectId];
		}
		catch(ArrayIndexOutOfBoundsException e) {
			SPObject.current = null;
		}
	}

	public void update(Graphics g) {
		paint(g);
	}
	
	public void paint(Graphics g) {
		if(pickingMap == null) {
			pickingMap = (BufferedImage)createImage(getWidth(), getHeight());	
			gPickingMap = pickingMap.createGraphics();
			bi = (BufferedImage)createImage(getWidth(), getHeight());	
			gBi = bi.createGraphics();
			gBi.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
			gBi.setFont(new Font("arial", Font.BOLD, 8));
		}
		
		gBi.setTransform(new AffineTransform());
		
		content.draw(gBi, SPObject.Style.VISUAL);
		content.draw(gPickingMap, SPObject.Style.ID);
		
		gBi.translate(cursorLocation.x, cursorLocation.y + 1);
		gBi.setStroke(shadowStroke);
		gBi.setColor(shadowColor);
		gBi.drawPolygon(x, y, 7);
		
		gBi.translate(0, -1);
		gBi.setStroke(cursorStroke);
		gBi.setColor(Color.black);
		gBi.fillPolygon(x, y, 7);
		gBi.setColor(Color.white);
		gBi.drawPolygon(x, y, 7);
		
		((Graphics2D)g).drawImage(bi, 0, 0, null);
	}

}